# install.packages("msos")
data("Spam", package = "msos")

library(shiny)

ui = shinyUI(fluidPage(
    titlePanel("Data Summarizer"),
    # Title
    sidebarLayout(
        sidebarPanel(
            h3("Data Selection"),
            # Note the ,
            # Dropdown
            selectInput("ds", # Name
                        "Choose a dataset:", # Label
                        choices = c("", "iris", "Spam", "mtcars")),
            numericInput("obs", # Name
                         "Number of Obs:", # Label
                         NULL),
            # Default Value
            submitButton("Load Preview Data") # Update data
        ),
        # close: sidebarPanel()
        mainPanel(
            h3("Head of the Dataset"),
            # HTML
            tableOutput("view"),
            # Table View
            h3("Dataset Summary"),
            # HTML
            verbatimTextOutput("summary") # Output Asis
        )
    )
))

server = shinyServer(function(input, output) {
    active_dataset = reactive({
        # Reactive
        req(input$ds) # Require input
        if (input$ds == "iris") {
            iris
        } else if (input$ds == "Spam") {
            Spam
        } else if (input$ds == "mtcars") {
            mtcars
        }
    }) # close: reactive()

    output$summary = renderPrint({
        # Summary Render
        summary(active_dataset())
    }) # close: renderPrint()

    output$view = renderTable({
        # Table Render
        req(input$obs) # Require input
        head(active_dataset(),
             n = input$obs)
    }) # close: renderPrint()

}) # close: shinyServer()

# Launch the App
shinyApp(ui = ui, server = server)
